@@ -3,7 +3,7 @@ package Dist::Zilla::PluginBundle::Author::SHARYANTO;
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
-our $VERSION = '0.13'; # VERSION
+our $VERSION = '0.14'; # VERSION
 
 use Dist::Zilla::PluginBundle::Filter;
 
@@ -19,6 +19,7 @@ sub configure {
         'Author::SHARYANTO::MetaResources',
         'CheckChangeLog',
         'CheckMetaResources',
+        'LogBuild',
         'MetaJSON',
         'OurPkgVersion',
         'PodWeaver',
@@ -43,7 +44,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -51,7 +52,7 @@ Dist::Zilla::PluginBundle::Author::SHARYANTO - Dist::Zilla like SHARYANTO when y
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
